spoon.spoonstream.SocketFile

Package spoon :: Module spoonstream :: Class SocketFile |
[hide private]
[frames] | no frames]

# Class SocketFile

source code

    object --+
             |
            SocketFile

Simple wrapper around a socket like object that pretends to be a file. Albeit one that can't seek or tell for obvious reasons.

Instance Methods | [hide private]
`` | __init__(self, sock) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | read(self, cnt=1)
`` | write(self, data)
`` | close(self)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, sock) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### read(self, cnt=1) | source code
None

### write(self, data) | source code
None

### close(self) | source code
None